@@ -232,6 +232,16 @@ cb_ui_theme_selection_changed (GtkTreeSelection *selection)
     theme_selection_changed (selection, "/Net/ThemeName");
 }
 
+static void
+cb_xfwm4_sync_switch_toggled (GObject *self, GParamSpec* pspec, gpointer user_data)
+{
+    /* Set the new XFWM4 theme */
+    if (gtk_switch_get_active (GTK_SWITCH (self)))
+        theme_selection_changed (GTK_TREE_SELECTION (user_data), "/Net/ThemeName");
+    else
+        xfconf_channel_set_string (xfconf_channel_get ("xfwm4"), "/general/theme", "Default");
+}
+
 static void
 cb_window_scaling_factor_combo_changed (GtkComboBox *combo)
 {
@@ -819,16 +829,30 @@ appearance_settings_dialog_channel_property_changed (XfconfChannel *channel,
         /* Keep gsettings in sync */
         if (desktop_interface_gsettings != NULL)
         {
+            GSettingsSchema *schema;
+
             str = xfconf_channel_get_string (channel, property_name, NULL);
             g_settings_set_string (desktop_interface_gsettings, "gtk-theme", str);
 
             /* Also set the preferred color scheme (needed for GTK4) */
-            if (str != NULL && g_str_has_suffix (str, "-dark"))
-                g_settings_set_string (desktop_interface_gsettings, "color-scheme", "prefer-dark");
-            else
-                g_settings_reset (desktop_interface_gsettings, "color-scheme");
+            g_object_get (desktop_interface_gsettings, "settings-schema", &schema, NULL);
+            if (g_settings_schema_has_key (schema, "color-scheme"))
+              {
+                if (str != NULL)
+                {
+                    gchar *strdown = g_ascii_strdown (str, -1);
+                    if (g_strstr_len (strdown, -1, "-dark-") || g_str_has_suffix (strdown, "-dark"))
+                        g_settings_set_string (desktop_interface_gsettings, "color-scheme", "prefer-dark");
+                    else
+                        g_settings_reset (desktop_interface_gsettings, "color-scheme");
+                    g_free (strdown);
+                }
+                else
+                    g_settings_reset (desktop_interface_gsettings, "color-scheme");
+              }
 
             g_free (str);
+            g_settings_schema_unref (schema);
         }
     }
     else if (strcmp (property_name, "/Net/IconThemeName") == 0)
@@ -1252,7 +1276,8 @@ appearance_settings_dialog_configure_widgets (GtkBuilder *builder)
     if (path != NULL)
     {
         object = gtk_builder_get_object (builder, "xfwm4_sync_switch");
-        xfconf_g_property_bind (xsettings_channel, "/Xfce/SyncThemes", G_TYPE_BOOLEAN, G_OBJECT (object), "state");
+        xfconf_g_property_bind (xsettings_channel, "/Xfce/SyncThemes", G_TYPE_BOOLEAN, G_OBJECT (object), "active");
+        g_signal_connect (G_OBJECT (object), "notify::active", G_CALLBACK (cb_xfwm4_sync_switch_toggled), selection);
     }
     else
     {
