@@ -527,9 +527,7 @@ xfce_displays_helper_screen_on_event (GdkXEvent *xevent,
 
     event_num = e->type - helper->event_base;
 
-    autoconnect_mode = xfconf_channel_get_int (helper->channel, NOTIFY_PROP, 1);
-
-    if (event_num == RRScreenChangeNotify && autoconnect_mode > 0)
+    if (event_num == RRScreenChangeNotify)
     {
         xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "RRScreenChangeNotify event received.");
 
@@ -539,12 +537,15 @@ xfce_displays_helper_screen_on_event (GdkXEvent *xevent,
         xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "Noutput: before = %d, after = %d.",
                         old_outputs->len, helper->outputs->len);
 
+        autoconnect_mode = xfconf_channel_get_int (helper->channel, NOTIFY_PROP, 1);
+
         /* Check if we have different amount of outputs and a matching profile and
            apply it if there's only one */
         if (old_outputs->len > helper->outputs->len ||
             old_outputs->len < helper->outputs->len)
         {
-            if (xfconf_channel_get_bool (helper->channel, AUTO_ENABLE_PROFILES, FALSE))
+            if (xfconf_channel_get_bool (helper->channel, AUTO_ENABLE_PROFILES, FALSE)
+                && autoconnect_mode > 0)
             {
                 gchar *matching_profile = NULL;
 
@@ -665,8 +666,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
             /* Start the minimal dialog according to the user preferences */
             if (changed && autoconnect_mode == 1)
-                xfce_spawn_command_line_on_screen (NULL, "xfce4-display-settings -m", FALSE,
-                                                   FALSE, NULL);
+                xfce_spawn_command_line (NULL, "xfce4-display-settings -m", FALSE, FALSE, TRUE, NULL);
         }
         g_ptr_array_unref (old_outputs);
     }
@@ -996,8 +996,6 @@ xfce_displays_helper_list_outputs (XfceDisplaysHelper *helper)
 
     g_assert (XFCE_IS_DISPLAYS_HELPER (helper) && helper->xdisplay && helper->resources);
 
-    outputs = g_ptr_array_new ();
-
     /* get all connected outputs */
     outputs = g_ptr_array_new_with_free_func ((GDestroyNotify) xfce_displays_helper_free_output);
     for (n = 0; n < helper->resources->noutput; ++n)
@@ -1535,7 +1533,7 @@ xfce_displays_helper_channel_apply (XfceDisplaysHelper *helper,
     /* safety check */
     if (nactive == 0)
     {
-        g_critical ("Stored Xfconf properties disable all outputs, aborting.");
+        g_warning ("Stored Xfconf properties disable all outputs, aborting.");
         goto err_cleanup;
     }
 
